SeekFrom

Enum SeekFrom 

1.0.0 · Source
pub enum SeekFrom {
    Start(u64),
    End(i64),
    Current(i64),
}
Enumeration of possible methods to seek within an I/O object.

It is used by the Seek trait.

Variants

1.0.0

Start(u64)

Sets the offset to the provided number of bytes.

1.0.0

End(i64)

Sets the offset to the size of this object plus the specified number of bytes.

It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.

1.0.0

Current(i64)

Sets the offset to the current position plus the specified number of bytes.

It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.