stream_len_default

Function stream_len_default 

#[doc(hidden)]
pub(crate) fn stream_len_default<T>(self_: &mut T) -> Result<u64, Error>
where T: Seek + ?Sized,
🔬This is a nightly-only experimental API. (core_io_internals)
The default implementation of Seek::stream_len. This may be desirable in libstd where the default implementation is desirable, but additional work needs to be done before or after.