#[non_exhaustive]pub struct Repeat {
#[doc(hidden)] pub byte: u8,
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.#[doc(hidden)]byte: u8🔬This is a nightly-only experimental API. (
core_io_internals)Trait Implementations
1.0.0 · Sourceimpl Read for Repeat
impl Read for Repeat
Sourcefn read_to_end(&mut self, _: &mut Vec<u8>) -> Result<usize>
fn read_to_end(&mut self, _: &mut Vec<u8>) -> Result<usize>
This function is not supported by io::Repeat, because there’s no end of its data
Sourcefn read_to_string(&mut self, _: &mut String) -> Result<usize>
fn read_to_string(&mut self, _: &mut String) -> Result<usize>
This function is not supported by io::Repeat, because there’s no end of its data
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Pull some bytes from this source into the specified buffer. Read more
Sourcefn read_buf_exact(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
fn read_buf_exact(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Reads the exact number of bytes required to fill
cursor. Read moreSourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector #69941)1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Read. Read more1.0.0 · Sourcefn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
fn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
Creates an adapter which will chain this stream with another. Read more