IoHandle

Trait IoHandle 

pub(crate) trait IoHandle { }
Marks that a type T can have IO traits such as Seek, Write, etc. automatically implemented for handle types like Arc as well.

This trait should only be implemented for types where <&T as Trait>::method(&mut &value, ..) would be identical to <T as Trait>::method(&mut value, ..).

File passes this test, as operations on &File and File both affect the same underlying file. [u8] fails, because any modification to &mut &[u8] would only affect a temporary and be lost after the method has been called.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors